==> haskell-process-extras-0.7.4-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-To8LGnalHnGruUrs8fJtu
key: process-extras-0.7.4-To8LGnalHnGruUrs8fJtu
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: 4bbfcf0c9b42b9f6dc7241c0b951c2a0
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.6.4/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-To8LGnalHnGruUrs8fJtu
depends:
    ListLike-4.6-Km5mU3w0RmBBNw483V7raw base-4.12.0.0
    bytestring-0.10.8.2 data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    deepseq-1.4.4.0 generic-deriving-1.12.3-hT23pHg9UZ4GQkmOyudsY
    mtl-2.2.2 process-1.6.5.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-RqOT2uDUXp4XNZNrBa2oy
key: process-extras-0.7.4-RqOT2uDUXp4XNZNrBa2oy
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: 9ddabda5ab1690f4458cfd07fc1d0447
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.6.4/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-RqOT2uDUXp4XNZNrBa2oy
depends:
    ListLike-4.6-Km5mU3w0RmBBNw483V7raw base-4.12.0.0
    bytestring-0.10.8.2 data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    deepseq-1.4.4.0 generic-deriving-1.12.3-CYFxhhO8c0AHmsgyEWjqe7
    mtl-2.2.2 process-1.6.5.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
